# EquinixLocationInfo


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**eq_billing_account_info_list** | [**[MultiCloudEdgeBillingAccountInfo]**](MultiCloudEdgeBillingAccountInfo.md) |  | [optional] 
**eq_ne_info** | [**EquinixNEInfo**](EquinixNEInfo.md) |  | [optional] 
**metro_code** | **str** |  | [optional] 
**metro_name** | **str** |  | [optional] 
**network_region** | **str** |  | [optional] 
**site_code** | **str** |  | [optional] 
**status** | **str** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


